========================
Team and repository tags
========================

.. image:: http://governance.openstack.org/badges/networking-calico.svg
    :target: http://governance.openstack.org/reference/tags/index.html

.. Change things from this point on

============
Introduction
============

This project contains code for integrating Project Calico's networking into
OpenStack/Neutron.

Calico is an open source solution for virtual networking in cloud data centers,
developed principally by Tigera and released under the Apache 2.0 License.

For general documentation about Calico, including how to get started with a
Calico/OpenStack installation, and how to use various OpenStack/Neutron
features with Calico, please see http://docs.projectcalico.org/master.

* Free software: Apache license
* Documentation: http://docs.projectcalico.org/master
* Source: http://git.openstack.org/cgit/openstack/networking-calico
* Bugs: http://bugs.launchpad.net/networking-calico
